Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(779)

Unified Diff: third_party/WebKit/Source/core/paint/ObjectPaintInvalidator.h

Issue 2465983002: Rename "paint invalidation rect" etc. to "visual rect". (Closed)
Patch Set: - Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/paint/ObjectPaintInvalidator.h
diff --git a/third_party/WebKit/Source/core/paint/ObjectPaintInvalidator.h b/third_party/WebKit/Source/core/paint/ObjectPaintInvalidator.h
index 3106edf031d97961c91b5d19ee21aa431feab2f2..5b95d3bc43b1d20e1921b495235a6f1276ef643d 100644
--- a/third_party/WebKit/Source/core/paint/ObjectPaintInvalidator.h
+++ b/third_party/WebKit/Source/core/paint/ObjectPaintInvalidator.h
@@ -43,7 +43,7 @@ class CORE_EXPORT ObjectPaintInvalidator {
void invalidateDisplayItemClientsIncludingNonCompositingDescendants(
PaintInvalidationReason);
- void invalidatePaintOfPreviousPaintInvalidationRect(
+ void invalidatePaintOfPreviousVisualRect(
const LayoutBoxModelObject& paintInvalidationContainer,
PaintInvalidationReason);
@@ -101,25 +101,25 @@ class ObjectPaintInvalidatorWithContext : public ObjectPaintInvalidator {
PaintInvalidationReason);
// This function tries to minimize the amount of invalidation generated by
// invalidating the "difference" between |m_context.oldBounds| and
// |m_context.newBounds|. This means invalidating the union of the previous
// rectangles but not their intersection. The use case is when an element only
// requires a paint invalidation (which means that its content didn't change)
// and its bounds changed but its location didn't. If we don't meet the
// criteria for an incremental paint, the alternative is a full paint
// invalidation. Returns true if any paint invalidation is done.
bool incrementallyInvalidatePaint();
private:
void invalidateSelectionIfNeeded(PaintInvalidationReason);
// This function generates a full invalidation, which means invalidating both
// |oldBounds| and |newBounds|. This is the default choice when generating an
// invalidation, as it is always correct, albeit it may force some extra
// painting.
void fullyInvalidatePaint(PaintInvalidationReason,
- const LayoutRect& oldBounds,
- const LayoutRect& newBounds);
+ const LayoutRect& oldVisualRect,
+ const LayoutRect& newVisualRect);
const PaintInvalidatorContext& m_context;
};
« no previous file with comments | « third_party/WebKit/Source/core/paint/GridPainter.cpp ('k') | third_party/WebKit/Source/core/paint/ObjectPaintInvalidator.cpp » ('j') | no next file with comments »
@@ -101,25 +101,25 @@ class ObjectPaintInvalidatorWithContext : public ObjectPaintInvalidator {
PaintInvalidationReason);
// This function tries to minimize the amount of invalidation generated by
- // invalidating the "difference" between |m_context.oldBounds| and
- // |m_context.newBounds|. This means invalidating the union of the previous
- // rectangles but not their intersection. The use case is when an element only
- // requires a paint invalidation (which means that its content didn't change)
- // and its bounds changed but its location didn't. If we don't meet the
- // criteria for an incremental paint, the alternative is a full paint
- // invalidation. Returns true if any paint invalidation is done.
+ // invalidating the "difference" between |m_context.oldVisualRect| and
+ // |m_context.newVisualRect|. This means invalidating the union of the
+ // previous rectangles excluding their intersection. The use case is when an
+ // element only requires a paint invalidation (which means that its content
+ // didn't change) and its bounds changed but its location didn't. If we don't
+ // meet the criteria for an incremental paint, the alternative is a full paint
+ // invalidation. Returns true if any paint invalidation is done.
bool incrementallyInvalidatePaint();
private:
@@ -101,25 +101,25 @@ class ObjectPaintInvalidatorWithContext : public ObjectPaintInvalidator {
void invalidateSelectionIfNeeded(PaintInvalidationReason);
// This function generates a full invalidation, which means invalidating both
- // |oldBounds| and |newBounds|. This is the default choice when generating an
- // invalidation, as it is always correct, albeit it may force some extra
- // painting.
+ // |oldVisualRect| and |newVisualRect|. This is the default choice when
+ // generating an invalidation, as it is always correct, albeit it may force
+ // some extra painting.
void fullyInvalidatePaint(PaintInvalidationReason,

Powered by Google App Engine
This is Rietveld 408576698